package jp.jsworld.SpModeMailWatcher;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Vibrator;
import android.preference.PreferenceManager;

/**
 * アプリケーション設定読込むクラスです。<br>
 *
 * @version 1.3.0
 * @author jun shiozaki
 *
 *         【ver. 1.4.0 2012/10/27】<br>
 *         ・getStopSoundScreenOn メソッドの追加<br>
 *         ・getStopViblationScreenOn メソッドの追加<br>
 *         ・getStopLedScreenOn メソッドの追加<br>
 *         ・getOffSoundCalling メソッドの追加<br>
 *         ・getOffViblationCalling メソッドの追加<br>
 *         ・getOffLedCalling メソッドの追加<br>
 *
 *         【ver. 1.3.0 2012/07/28】<br>
 *         ・getStopCallScreenOn メソッドの追加<br>
 *         ・getShowControlWinodow メソッドの追加<br>
 *         ・setNoticeSoundFlag メソッドの追加<br>
 *         ・getShowInformation メソッドの追加<br>
 *         ・setShowInformation メソッドの追加<br>
 *
 *         【ver. 1.2.6 2012/07/08】<br>
 *         ・getNewMailSpanTime メソッドの追加<br>
 *         ・getNoticeSoundPlayTimeText メソッドの追加<br>
 *
 *         【ver. 1.2.4 2012/06/23】<br>
 *         ・getCallingTime メソッドの削除<br>
 *         ・getNoticeSoundPlayTime メソッドの追加<br>
 *         ・getNoticeVibrateTime メソッドの追加<br>
 *
 *         【ver. 1.2.0 2012/06/03】 <br>
 *         ・通知LEDの設定を取得するメソッドの追加<br>
 *         getNoticeLedFlag、getLedColor、getLedColorValue、getLedColorText<br>
 *
 *         【ver. 1.1.0 2012/05/03】 <br>
 *         ・SPモードメールを受信するメーラーを取得するメソッドの追加<br>
 *         getMailer、getMailerName<br>
 *         ・CommuniCase 使用時のSPモードメールアカウントを取得するメソッドの追加<br>
 *         getAccountName<br>
 *         ・未受信テキストを取得するメソッドの追加<br>
 *         getUnReceivedMailText<br>
 */
public class SettingReader {

    // 定数
    public static final String MAILER_SPMODE = "spmodemail";
    public static final String MAILER_COMMUNICASE = "communicase";

    // プリファレンス
    SharedPreferences pre = null;

    // コンテキスト
    Context context = null;

    /**
     * クラスの初期化を行います。
     *
     * @param context
     *            コンテキスト
     */
    public SettingReader(Context context) {
        this.context = context;

        // デフォルトのプリファレンスの取得
        this.pre = PreferenceManager.getDefaultSharedPreferences(context);
    }

    /**
     * メーラーを取得します。
     *
     * @return
     */
    public String getMailer() {
        return pre.getString(this.context.getText(R.string.list_mailer)
                .toString(), MAILER_SPMODE);
    }

    /**
     * メーラーの名前を取得します。
     *
     * @param mailer
     *            メーラー
     *
     * @return
     */
    public String getMailerName(String mailer) {
        String mailerName = "";

        if (MAILER_SPMODE.equals(mailer)) {
            mailerName = "spモードメール";
        } else if (MAILER_COMMUNICASE.equals(mailer)) {
            mailerName = "CommuniCase";
        }

        return mailerName;
    }

    /**
     * CommuniCase 使用時のアカウント名を取得します。
     *
     * @return
     */
    public String getAccountName() {
        return pre.getString(this.context.getText(R.string.edit_account_name)
                .toString(), "ドコモ");
    }

    /**
     * 通知時に音を鳴らすかどうかを取得します。
     *
     * @return
     */
    public boolean getNoticeSoundFlag() {
        return pre.getBoolean(
                this.context.getText(R.string.check_notice_soundflag)
                        .toString(), true);
    }

    /**
     * 通知時に音を鳴らすかどうかを設定します。
     *
     * @param value
     *            設定値
     */
    public void setNoticeSoundFlag(boolean value) {
        //
        SharedPreferences.Editor editor = pre.edit();
        editor.putBoolean(this.context.getText(R.string.check_notice_soundflag)
                .toString(), value);
        editor.commit();
    }

    /**
     * 通知時に鳴らす音のファイル名を取得します。
     *
     * @return
     */
    public String getSoundName() {
        return pre.getString(
                this.context.getText(R.string.ringtone_notice_soundname)
                        .toString(), "content://settings/system/ringtone");
    }

    /**
     * 通知時に鳴らす音の長さを取得します。
     *
     * @return
     */
    public long getNoticeSoundPlayTime() {
        long callingTime;

        String callingTimeValue = pre.getString(
                this.context.getText(R.string.list_notice_soundplaytime)
                        .toString(), "5");
        try {
            callingTime = Long.parseLong(callingTimeValue);
        } catch (NumberFormatException e) {
            callingTime = Long.valueOf(5);
        }

        return callingTime;
    }

    /**
     * 通知時にバイブレーターを動作させるかを取得します。
     *
     * @return
     */
    public boolean getNoticeVibrateFlag() {
        return pre.getBoolean(
                this.context.getText(R.string.check_notice_vibrateflag)
                        .toString(), true);
    }

    /**
     * 通知のバイブレーターのパターンを取得します。
     *
     * @return
     */
    public String getVibratePattern() {
        return pre.getString(
                this.context.getText(R.string.list_notice_vibrateptn)
                        .toString(), "1");
    }

    /**
     * 通知時のバイブレーターの長さを取得します。
     *
     * @return
     */
    public long getNoticeVibrateTime() {
        long callingTime;

        String callingTimeValue = pre.getString(
                this.context.getText(R.string.list_notice_vibratetime)
                        .toString(), "5");
        try {
            callingTime = Long.parseLong(callingTimeValue);
        } catch (NumberFormatException e) {
            callingTime = Long.valueOf(5);
        }

        return callingTime;
    }

    /**
     * 通知を受けてからアプリで通知するまでの待ち時間秒で設定します。
     *
     * @return
     */
    public long getWaittime() {
        long waittime;

        String waittimeValue = pre.getString(
                this.context.getText(R.string.list_notice_waittime).toString(),
                "4");
        try {
            waittime = Long.parseLong(waittimeValue);
        } catch (NumberFormatException e) {
            waittime = Long.valueOf(3);
        }

        return waittime;
    }

    /**
     * 新着メールを受信してから、未受信メールを無視する時間を設定します。
     *
     * @return
     */
    public long getNewMailSpanTime() {
        long spantime;

        String spantimeValue = pre
                .getString(this.context.getText(R.string.list_newmail_spantime)
                        .toString(), "60");
        try {
            spantime = Long.parseLong(spantimeValue);
        } catch (NumberFormatException e) {
            spantime = Long.valueOf(3);
        }

        return spantime;
    }

    /**
     * プレファレンスで設定されているパターンのバイブレーターを取得します。
     *
     * @param vibratePtn
     *            パターン
     * @return
     */
    public Vibrator getVibrator(String vibratePtn, int repeat) {
        long[] ptn;

        // バイブレーターの取得k
        Vibrator vibrator = (Vibrator) context
                .getSystemService(Context.VIBRATOR_SERVICE);

        if ("1".equals(vibratePtn)) {
            ptn = new long[] { 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000 };
        } else if ("2".equals(vibratePtn)) {
            ptn = new long[] { 500, 500, 500, 500, 500, 500, 500, 500 };
        } else if ("3".equals(vibratePtn)) {
            ptn = new long[] { 500, 1000, 500, 500, 500, 1000, 500, 500 };
        } else if ("4".equals(vibratePtn)) {
            ptn = new long[] { 1000, 500, 1000, 500, 1000, 500, 1000, 500 };
        } else if ("5".equals(vibratePtn)) {
            ptn = new long[] { 1000, 2000, 1000, 2000, 1000, 2000, 1000, 2000 };
        } else {
            ptn = new long[] { 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000 };
        }

        vibrator.vibrate(ptn, repeat);

        return vibrator;
    }

    /**
     * 未受信メールのテキストを取得します。
     *
     * @return
     */
    public String getUnReceivedMailText() {
        String unReceiveMailText = "";

        if (MAILER_SPMODE.equals(this.getMailer())) {
            unReceiveMailText = "未受信メール";
        } else if (MAILER_COMMUNICASE.equals(this.getMailer())) {
            unReceiveMailText = "未受信メールがあります（" + this.getAccountName() + "）";
        }

        return unReceiveMailText;
    }

    /**
     * 通知時にLEDを発光させるかを取得します。
     *
     * @return
     */
    public boolean getNoticeLedFlag() {
        return pre.getBoolean(
                this.context.getText(R.string.check_notice_ledflag).toString(),
                false);
    }

    /**
     * プレファレンスで設定されているパターンのLED色を取得します。
     *
     * @return
     */
    public String getLedColor() {
        return pre.getString(this.context
                .getText(R.string.list_notice_ledcolor).toString(), "3");
    }

    /**
     * LED色のテキストを取得します。
     *
     * @param ledColor
     *            LED色
     *
     * @return
     */
    public String getLedColorText(String ledColor) {
        String ledColorText = "";

        if ("0".equals(ledColor)) {
            ledColorText = "白";
        } else if ("1".equals(ledColor)) {
            ledColorText = "赤";
        } else if ("2".equals(ledColor)) {
            ledColorText = "緑";
        } else if ("3".equals(ledColor)) {
            ledColorText = "青";
        } else if ("4".equals(ledColor)) {
            ledColorText = "黄";
        } else if ("5".equals(ledColor)) {
            ledColorText = "シアン";
        } else if ("6".equals(ledColor)) {
            ledColorText = "マゼンダ";
        }

        return ledColorText;
    }

    /**
     * LED色のRGB値をを取得します。
     *
     * @param ledColor
     *            LED色
     *
     * @return LED色テキスト
     */
    public int getLedColorRGB(String ledColor) {
        int ledColorValue = 0xff000000;

        if ("0".equals(ledColor)) {
            // 白
            ledColorValue = 0xffffffff;
        } else if ("1".equals(ledColor)) {
            // 赤
            ledColorValue = 0xffff0000;
        } else if ("2".equals(ledColor)) {
            // 緑
            ledColorValue = 0xff00ff00;
        } else if ("3".equals(ledColor)) {
            // 青
            ledColorValue = 0xff0000ff;
        } else if ("4".equals(ledColor)) {
            // 黄
            ledColorValue = 0xffffff00;
        } else if ("5".equals(ledColor)) {
            // シアン
            ledColorValue = 0xff00ffff;
        } else if ("6".equals(ledColor)) {
            // マゼンダ
            ledColorValue = 0xffff00ff;
        }

        return ledColorValue;
    }

    /**
     * 通知時に鳴らす音の長さのテキストを取得します。
     *
     * @param playtime
     *            再生時間
     *
     * @return 再生時間テキスト
     */
    public String getNoticeSoundPlayTimeText(String soundPlayTime) {
        String soundPlayTimeText = soundPlayTime + "秒";

        if ("0".equals(soundPlayTime)) {
            soundPlayTimeText = "曲の長さ";
        }

        return soundPlayTimeText;
    }

    /**
     * 通知中に操作画面を表示するかどうかを取得します。
     *
     * @return
     */
    public boolean getShowControlWinodow() {
        return pre
                .getBoolean(this.context
                        .getText(R.string.check_show_ctrlwindow).toString(),
                        false);
    }

    /**
     * インフォメーションを表示するかどうかを取得します。
     *
     * @return
     */
    public boolean getShowInformation() {
        return pre.getBoolean(
                this.context.getText(R.string.check_show_information)
                        .toString(), true);
    }

    /**
     * インフォメーションを表示するかどうかを設定します。
     *
     * @param value
     *            設定値
     */
    public void setShowInformation(boolean value) {
        //
        SharedPreferences.Editor editor = pre.edit();
        editor.putBoolean(this.context.getText(R.string.check_show_information)
                .toString(), value);
        editor.commit();
    }

    /**
     * 画面電源ONで着信音停止するかどうかを取得します。
     *
     * @return
     */
    public boolean getStopSoundScreenOn() {
        return pre
                .getBoolean(this.context
                        .getText(R.string.check_scron_soundstop).toString(),
                        true);
    }

    /**
     * 画面電源ONでバイブレーター停止するかどうかを取得します。
     *
     * @return
     */
    public boolean getStopViblationScreenOn() {
        return pre.getBoolean(
                this.context.getText(R.string.check_scron_viblationstop)
                        .toString(), true);
    }

    /**
     * 画面電源ONでLED点滅を停止するかどうかを取得します。
     *
     * @return
     */
    public boolean getStopLedScreenOn() {
        return pre.getBoolean(this.context
                .getText(R.string.check_scron_ledstop).toString(), true);
    }

    /**
     * 通話中はメール通知の着信音をOFFにします。
     *
     * @return
     */
    public boolean getOffSoundCalling() {
        return pre.getBoolean(
                this.context.getText(R.string.check_calling_soundoff)
                        .toString(), true);
    }

    /**
     * 通話中はメール通知のバイブレーターをOFFにします。
     *
     * @return
     */
    public boolean getOffViblationCalling() {
        return pre.getBoolean(
                this.context.getText(R.string.check_calling_viblationoff)
                        .toString(), true);
    }

    /**
     * 通話中はメール通知のLED点滅をOFFにします。
     *
     * @return
     */
    public boolean getOffLedCalling() {
        return pre.getBoolean(
                this.context.getText(R.string.check_calling_ledoff).toString(),
                true);
    }

}
